/****************************************************************************
 *
 * MODULE:             Intelligent Peripheral Interface
 *
 * COMPONENT:          $RCSfile: $
 *
 * VERSION:            $Name: $
 *
 * REVISION:           $Revision: $
 *
 * DATED:              $Date: $
 *
 * STATUS:             $State: $
 *
 * AUTHOR:             Mozammul Ahmed
 *
 * DESCRIPTION:
 * Debug Functions
 *
 * LAST MODIFIED BY:   $Author:  $
 *                     $Modtime: $
 *
 *
 ****************************************************************************
 *
 *  (c) Copyright 2000 JENNIC Ltd
 *
 ****************************************************************************/

/****************************************************************************/
/***        Include files                                                 ***/
/****************************************************************************/

#include <AppHardwareApi.h>
#include "debug.h"

/****************************************************************************/
/***        Macro Definitions                                             ***/
/****************************************************************************/

/****************************************************************************/
/***        Type Definitions                                              ***/
/****************************************************************************/

/****************************************************************************/
/***        Local Function Prototypes                                     ***/
/****************************************************************************/

/****************************************************************************/
/***        Exported Variables                                            ***/
/****************************************************************************/

/****************************************************************************/
/***        Local Variables                                               ***/
/****************************************************************************/

/****************************************************************************/
/***        Exported Functions                                            ***/
/****************************************************************************/

/****************************************************************************
 *
 * NAME:       vDebug_Init
 *
 * DESCRIPTION:
 * Initialise IP host interface.
 *
 * PARAMETERS: None
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
PUBLIC void vDebug_Init(void)
{
    /* Enable UART 0 for debug output */
    vAHI_UartEnable(0);
    vAHI_UartReset(0, TRUE, TRUE);
    vAHI_UartSetClockDivisor(0, E_AHI_UART_RATE_38400);
    vAHI_UartReset(0, FALSE, FALSE);
}

/****************************************************************************
 *
 * NAME: vDebug
 *
 * DESCRIPTION:
 * Sends a string to UART0 using the hardware API.
 *
 * PARAMETERS:      Name            RW  Usage
 *                  pcMessage       R   Null-terminated message to send
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
PUBLIC void vDebug(char *pcMessage)
{
    while (*pcMessage)
    {
        while ((u8AHI_UartReadLineStatus(0) & 0x20) == 0);
        vAHI_UartWriteData(0, *pcMessage);
        pcMessage++;
    }
}

/****************************************************************************
 *
 * NAME: vDisplayHex
 *
 * DESCRIPTION:
 * Sends a string to UART0 using the hardware API.
 *
 * PARAMETERS:      Name            RW  Usage
 *                  pcMessage       R   Null-terminated message to send
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
PUBLIC void vDisplayHex(uint32 u32Data)
{
    char acValue[9];
    char *pcString = acValue;
    uint8 u8Nybble;
    int i, j;

    j = 0;
    for (i = 28; i >= 0; i -= 4)
    {
        u8Nybble = (uint8)((u32Data >> i) & 0x0f);
        u8Nybble += 0x30;
        if (u8Nybble > 0x39)
            u8Nybble += 7;

        *pcString = u8Nybble;
        pcString++;
    }
    *pcString = '\0';

    vDebug(acValue);
}

/****************************************************************************/
/***        Local Functions                                               ***/
/****************************************************************************/

/****************************************************************************/
/***        END OF FILE                                                   ***/
/****************************************************************************/
