/****************************************************************************
 *
 * MODULE:             IP Test Application
 *
 * COMPONENT:          $RCSfile:  $
 *
 * VERSION:            $Name:  $
 *
 * REVISION:           $Revision: $
 *
 * DATED:              $Date: $
 *
 * STATUS:             $State: $
 *
 * AUTHOR:             Mozammul Ahmed
 *
 * DESCRIPTION:
 * Simple application to test IP mode operation
 *
 * LAST MODIFIED BY:   $Author:  $
 *                     $Modtime: $
 *
 ****************************************************************************
 *
 *  (c) Copyright 2003 JENNIC Ltd
 *
 ****************************************************************************/

/****************************************************************************/
/***        Include files                                                 ***/
/****************************************************************************/

#include "jendefs.h"
#include <AppHardwareApi.h>
#include <AppQueueApi.h>
#include <Button.h>
#include "ip.h"
#include "debug.h"

/****************************************************************************/
/***        Macro Definitions                                             ***/
/****************************************************************************/
#define     MSG_LENGTH   13
/****************************************************************************/
/***        Type Definitions                                              ***/
/****************************************************************************/

/****************************************************************************/
/***        Local Function Prototypes                                     ***/
/****************************************************************************/

PRIVATE void vHandleRxMsg(uint8 u8Length, uint8 *pau8Data);

/****************************************************************************/
/***        Exported Variables                                            ***/
/****************************************************************************/

/****************************************************************************/
/***        Local Variables                                               ***/
/****************************************************************************/

/****************************************************************************/
/***        Exported Functions                                            ***/
/****************************************************************************/
/****************************************************************************
 *
 * NAME: AppColdStart
 *
 * DESCRIPTION:
 * Simple application to flash an LED.
 *
 * RETURNS:
 * void, but never returns
 *
 ****************************************************************************/
PUBLIC void AppColdStart(void)
{
    uint8 au8TxMsg[MSG_LENGTH*4];
    uint8 i, j;

    (void)u32AppQApiInit(NULL, NULL, NULL);
    (void)u32AHI_Init();

    vAHI_WatchdogStop();

    vButtonInitRfd();

    vDebug_Init();
    vDebug("InitMstr\r\n");

    vIP_Init();

    /* register callback */
    vIP_RegisterCallback(vHandleRxMsg);

    for(i=0; i<MSG_LENGTH; i++)
    {
        j = i*4;
        /* 32 bit data - MSB first */
        au8TxMsg[j]= 0;
        au8TxMsg[j+1]= 0;
        au8TxMsg[j+2]= i;
        au8TxMsg[j+3]= 0;
    }
    vDebug("MsgRdy\r\n");

    bIP_MsgPrepare(MSG_LENGTH,(uint8*) &au8TxMsg);
    while(TRUE)
    {
        if (u8ButtonReadRfd() & BUTTON_0_MASK)
        {
            bIP_MsgPrepare(MSG_LENGTH, NULL);

			vDebug("Snt\r\n");
			vIP_Communicate();
			vDebug("CommOk\r\n");
        }
    }

}

PUBLIC void AppWarmStart(void)
{
    AppColdStart();
}

/****************************************************************************/
/***        Local Functions                                               ***/
/****************************************************************************/
/****************************************************************************
 *
 * NAME: vHandleRxMsg
 *
 * DESCRIPTION:
 * function called when message received over IP interface
 *
 * PARAMETERS:      Name            RW  Usage
 *                  u8Length        R   length of received data in words
 *                  pau8Data        R   ptr to data (MSB first)
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
PRIVATE void vHandleRxMsg(uint8 u8Length, uint8 *pau8Data)
{
    uint8 i;

    vDebug("Msg Recvd ");
    vDisplayHex((uint32) u8Length);
    vDebug("\r\n");

    for (i=0; i<u8Length; i++)
    {
        vDisplayHex( (uint32) i);
        vDebug(" ");
        vDisplayHex( *((uint32*) &pau8Data[i*4]) );
        vDebug("\r\n");
    }
}

/****************************************************************************/
/***        END OF FILE                                                   ***/
/****************************************************************************/
