/****************************************************************************
 *
 * MODULE:             IP Test Application
 *
 * COMPONENT:          $RCSfile:  $
 *
 * VERSION:            $Name:  $
 *
 * REVISION:           $Revision: $
 *
 * DATED:              $Date: $
 *
 * STATUS:             $State: $
 *
 * AUTHOR:             Mozammul Ahmed
 *
 * DESCRIPTION:
 * Simple application to test IP mode operation
 *
 * LAST MODIFIED BY:   $Author:  $
 *                     $Modtime: $
 *
 ****************************************************************************
 *
 *  (c) Copyright 2003 JENNIC Ltd
 *
 ****************************************************************************/

/****************************************************************************/
/***        Include files                                                 ***/
/****************************************************************************/

#include "jendefs.h"
#include <AppHardwareApi.h>
#include <AppQueueApi.h>
#include <PeripheralRegs_JN514x.h>
#include "debug.h"
#include "ip.h"
#include "debug.h"
/****************************************************************************/
/***        Macro Definitions                                             ***/
/****************************************************************************/
#define     MSG_SIZE        20
#define     MAX_MSG_BYTES   (MSG_SIZE * 4)
/****************************************************************************/
/***        Type Definitions                                              ***/
/****************************************************************************/

/****************************************************************************/
/***        Local Function Prototypes                                     ***/
/****************************************************************************/

PRIVATE void vHandleInterrupt(uint32 u32Device, uint32 u32ItemBitmap);
PRIVATE void vPrintMsg(uint8 u8Length, uint8* pau8Data);

/****************************************************************************/
/***        Exported Variables                                            ***/
/****************************************************************************/

/****************************************************************************/
/***        Local Variables                                               ***/
/****************************************************************************/

PRIVATE uint8 au8TxMsg[E_AHI_IP_MAX_MSG_SIZE*4];
PRIVATE uint8 au8RxMsg[E_AHI_IP_MAX_MSG_SIZE*4];

PRIVATE uint8 u8RxMsgLength;

PRIVATE volatile bool_t bTxDone = TRUE;
PRIVATE volatile bool_t bRxDone = FALSE;

/****************************************************************************/
/***        Exported Functions                                            ***/
/****************************************************************************/
/****************************************************************************
 *
 * NAME: AppColdStart
 *
 * DESCRIPTION:
 * Simple application to flash an LED.
 *
 * RETURNS:
 * void, but never returns
 *
 ****************************************************************************/
PUBLIC void AppColdStart(void)
{
    uint16 i,j;

    (void)u32AppQApiInit(NULL, NULL, NULL);
    (void)u32AHI_Init();

    vAHI_WatchdogStop();

    /* Enable debug output */
    vDebug_Init();
    vDebug("InitSlv\r\n");

    /* configure data sampling */
    //vAHI_IpEnable(E_AHI_IP_TXPOS_EDGE, E_AHI_IP_RXPOS_EDGE, E_AHI_IP_BIG_ENDIAN);
    vAHI_IpEnable(E_AHI_IP_TXPOS_EDGE, E_AHI_IP_RXPOS_EDGE, FALSE);
    vDebug("IpEnbld\r\n");

    /* register callback */
    vAHI_IpRegisterCallback(vHandleInterrupt);

    /* enable wakeup on slave select */
    vAHI_DioInterruptEnable (E_AHI_DIO17_INT, 0);
    vAHI_DioInterruptEdge (0, E_AHI_DIO17_INT);

    vDebug("CallbkReg\r\n");

    for(i=0; i<MSG_SIZE; i++)
    {
        j = i*4;
        /* 32 bit data - MSB first */
        au8TxMsg[j]= i;
        au8TxMsg[j+1]= 0;
        au8TxMsg[j+2]= 0;
        au8TxMsg[j+3]= 0;
    }
    vDebug("MsgRdy\r\n");

    u8RxMsgLength = 20;
    while(TRUE)
    {
    	// Store Sending Data
    	uint32 *p = (uint32*)au8TxMsg;
    	for (i = 0; i < MAX_MSG_BYTES; i++) {
    		p[i]++;
    	}
        bAHI_IpSendData(MSG_SIZE,(uint8*)au8TxMsg, E_AHI_IP_BIG_ENDIAN);

        // This API does not work ;-(
    	// bAHI_IpReadData(&u8RxMsgLength, (uint8*)(au8RxMsg), E_AHI_IP_BIG_ENDIAN);

        // Set Receiving buffer as Ready to Receive.
        vAHI_IpReadyToReceive();

        /* msg will be transferred when master starts interface clock
           CPU will wakeup when slave select is pulled low */
        vAHI_CpuDoze();

        vDebug("SPI Interrupt:\r\n");

#undef USE_REG_READ
        // is blocking here adequate???
        while (!bAHI_IpRxDataAvailable()) {}
#ifdef USE_REG_READ
        u8RxMsgLength = apvSpiIpReg[2] & 0xFF;
#else
    	bAHI_IpReadData(&u8RxMsgLength, (uint8*)(au8RxMsg), E_AHI_IP_BIG_ENDIAN);
#endif

        if (u8RxMsgLength) {
            // number of received data MAX: E_AHI_IP_MAX_MSG_SIZE (0x3E)
        	vDebug("MsgRcvd\r\n");

#ifdef USE_REG_READ
        	int i;
        	uint32 *p = (uint32*)au8RxMsg;
        	for(i = 0; i < u8RxMsgLength; i++) {
        		p[i] = apvSpiIpMem[i];
        	}
#endif

        	// display the result
           	vPrintMsg(u8RxMsgLength, au8RxMsg);
        }

        vAHI_IpReadyToReceive(); // now it can receive new data.
    }
}

PUBLIC void AppWarmStart(void)
{
    AppColdStart();
}

/****************************************************************************/
/***        Local Functions                                               ***/
/****************************************************************************/
/****************************************************************************
 *
 * NAME: vHandleInterrupt
 *
 * DESCRIPTION:
 * function called when message sent/received over IP interface
 *
 * PARAMETERS:      Name            RW  Usage
 *                  u32Device        R  always IP interface ID
 *                  u32ItemBitmap    R  contents of IP Status Reg
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
PRIVATE void vHandleInterrupt(uint32 u32Device, uint32 u32ItemBitmap)
{
	// Here, the complete data has not been arrived.
}

/****************************************************************************
 *
 * NAME: vPrintMsg
 *
 * DESCRIPTION:
 * Prints the message a binary word at a time to UART0 using the debug calls.
 *
 * PARAMETERS:
 * None
 *
 * RETURNS:
 * void
 *
 ****************************************************************************/
PRIVATE void vPrintMsg(uint8 u8Length, uint8 *pau8Data)
{
    uint8 i, j;
    uint32 u32DataWord;

    vDebug("MsgLngth ");
    vDisplayHex( (uint32) u8Length);
    vDebug("\r\n");

    for (i=0; i<u8Length; i++)
    {
        j = i*4;
        vDisplayHex( (uint32) i);
        vDebug(" ");

        u32DataWord = pau8Data[j+3];
        u32DataWord |= (pau8Data[j+2] << 8);
        u32DataWord |= (pau8Data[j+1] << 16);
        u32DataWord |= (pau8Data[j] << 24);

        vDisplayHex(u32DataWord);
        vDebug("\r\n");
    }
}

/****************************************************************************/
/***        END OF FILE                                                   ***/
/****************************************************************************/
